gnulib: Modules imported from Gnulib
====================================

This script package represents the modules imported into the Sage source tree from Gnulib.

Upstream Contact
----------------

https://www.gnu.org/software/gnulib/
